=======
History
=======

1.0b2 (2018-04-20)
------------------

- Add a parameter to use the testing environment of the Payment service.
  [erral]


1.0b1 (2018-04-18)
------------------

* Implementation of notebook 60 payments in short format (521)
  [erral]
